package com.atguigu.ssyx.cart.controller;

import com.atguigu.ssyx.cart.service.CartInfoService;
import com.atguigu.ssyx.common.context.BaseContext;
import com.atguigu.ssyx.common.result.Result;
import com.atguigu.ssyx.model.order.CartInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Api(tags = "购物车相关接口")
@RestController
@RequestMapping("/api/cart")
public class CartApiController {
    @Autowired
    private CartInfoService cartInfoService;

    @ApiOperation(value = "添加购物车")
    @GetMapping("addToCart/{skuId}/{skuNum}")
    public Result<CartInfo> addToCart(@PathVariable Long skuId, @PathVariable Integer skuNum) {
        Long userId = BaseContext.getUserId();
        cartInfoService.addToCart(skuId, userId, skuNum);
        return Result.success();
    }

    @ApiOperation(value = "删除购物车内容")
    @DeleteMapping("deleteCart/{skuId}")
    public Result<CartInfo> deleteCart(@PathVariable Long skuId) {
        Long userId = BaseContext.getUserId();
        cartInfoService.deleteCart(skuId, userId);
        return Result.success();
    }

    @ApiOperation(value = "清空购物车")
    @DeleteMapping("deleteAllCart")
    public Result<CartInfo> deleteAllCart() {
        Long userId = BaseContext.getUserId();
        cartInfoService.deleteAllCart(userId);
        return Result.success();
    }

    @ApiOperation(value = "批量删除购物车")
    @PostMapping("batchDeleteCart")
    public Result<CartInfo> batchDeleteCart(@RequestBody List<Long> skuIdList) {
        Long userId = BaseContext.getUserId();
        cartInfoService.batchDeleteCart(userId, skuIdList);
        return Result.success();
    }
}
